<?php

namespace GiveMollie\Actions;

use Exception;
use Give\Donations\Models\Donation;
use Give\Framework\PaymentGateways\Exceptions\PaymentGatewayException;
use GiveMollie\API\MollieApi;
use Mollie\Api\MollieApiClient;
use Mollie\Api\Resources\Customer;

/**
 * @since 2.0.0
 */
class CreateMollieCustomer
{
    /**
     * @since 2.0.0
     *
     * @throws PaymentGatewayException
     */
    public function __invoke(Donation $donation): Customer
    {
        try {
            $mollieCustomer = MollieApi::client()->customers->create(
                [
                    'name' => $donation->donor->name,
                    'email' => $donation->donor->email,
                ]
            );

            Give()->donor_meta->update_meta($donation->donorId, MollieApi::getCustomerMetaKey(),
                $mollieCustomer->id);

            /**
             * Customer created
             *
             * @since 2.0.0
             *
             * @param MollieApiClient $customer
             */
            do_action('givewp_mollie_customer_created', $mollieCustomer);

            return $mollieCustomer;
        } catch (Exception $e) {
            throw new PaymentGatewayException(
                sprintf(
                    __('[Mollie] Customer not created. API Error: %s', 'give-mollie'),
                    $e->getCode() . ' - ' . $e->getMessage()
                )
            );
        }
    }
}
