<?php

namespace GiveMollie\Actions;

use Exception;
use Give\Donations\Models\Donation;
use Give\Framework\PaymentGateways\Exceptions\PaymentGatewayException;
use Mollie\Api\Resources\Payment;

/**
 * @since 2.0.0
 */
class CreateMolliePayment
{
    /**
     * @since 2.0.0
     *
     * @throws PaymentGatewayException
     */
    public function __invoke(Donation $donation, $paymentParameters): Payment
    {
        try {
            $mollieCustomer = (new GetMollieCustomer())($donation);
            $molliePayment = $mollieCustomer->createPayment($paymentParameters);

            /**
             * After payment created
             *
             * @since 2.0.0
             *
             * @param Payment $payment
             */
            do_action('givewp_mollie_after_payment_created', $molliePayment);

            return $molliePayment;
        } catch (Exception $e) {
            throw new PaymentGatewayException(
                sprintf(
                    __('[Mollie] Payment not created. API Error: %s', 'give-mollie'),
                    $e->getCode() . ' - ' . $e->getMessage()
                )
            );
        }
    }
}
