<?php

namespace GiveMollie\Actions;

use Exception;
use Give\Donations\Models\Donation;
use Give\Framework\PaymentGateways\Exceptions\PaymentGatewayException;
use GiveMollie\API\MollieApi;
use Mollie\Api\Resources\Customer;

/**
 * @since 2.0.0
 */
class GetMollieCustomer
{
    /**
     * @since 2.0.0
     *
     * @throws PaymentGatewayException
     */
    public function __invoke(Donation $donation): Customer
    {
        try {
            $mollieCustomerId = Give()->donor_meta->get_meta($donation->donorId, MollieApi::getCustomerMetaKey(),
                true);

            if (empty($mollieCustomerId)) {
                return (new CreateMollieCustomer())($donation);
            }

            return MollieApi::client()->customers->get($mollieCustomerId);
        } catch (Exception $e) {
            throw new PaymentGatewayException(
                sprintf(
                    __('[Mollie] Customer not found. API Error: %s', 'give-mollie'),
                    $e->getCode() . ' - ' . $e->getMessage()
                )
            );
        }
    }
}
