<?php

namespace GiveMollie\Actions;

use Exception;
use Give\Donations\Models\Donation;
use Give\Framework\PaymentGateways\Exceptions\PaymentGatewayException;
use GiveMollie\API\MollieApi;

/**
 * @since 2.0.0
 */
class RefundMolliePayment
{
    /**
     * @since 2.0.0
     *
     * @throws PaymentGatewayException
     */
    public function __invoke(Donation $donation)
    {
        if ( ! $donation->gatewayTransactionId) {
            throw new PaymentGatewayException(__('[Mollie] The transaction id was not provided during an attempted refund. Check the donation details and ensure that the transaction ID is present and matches the one from the gateway.',
                'give-mollie'));
        }

        try {
            $molliePayment = MollieApi::client()->payments->get($donation->gatewayTransactionId);

            if ( ! $molliePayment->canBeRefunded()) {
                throw new PaymentGatewayException(__('[Mollie] The transaction cant\'t be refunded.', 'give-mollie'));
            }

            $refund = $molliePayment->refund([
                'amount' => [
                    'value' => $donation->amount->formatToDecimal(),
                    'currency' => $donation->amount->getCurrency()->getCode(),
                ],
            ]);

            $refundMetaData = [
                'id' => $refund->id,
                'amount' => $refund->amount,
                'status' => $refund->status,
                'refund_date_time' => $refund->createdAt,
            ];

            give_update_payment_meta($donation->id, '_give_mollie_refund_data', $refundMetaData);
        } catch (Exception $e) {
            throw new PaymentGatewayException(
                sprintf(
                    __('[Mollie] Refund failed for donation %s. The refund can be initiated on the gateway side, or try again here. API Error: %s',
                        'give-mollie'),
                    $donation->id,
                    $e->getCode() . ' - ' . $e->getMessage()
                )
            );
        }
    }
}
