<?php

namespace GiveMollie\DataTransferObjects;

use Give\Framework\PaymentGateways\Exceptions\PaymentGatewayException;
use GiveMollie\API\MollieApi;
use Mollie\Api\Exceptions\ApiException;
use Mollie\Api\Resources\Payment;

/**
 * @since 2.0.0
 */
class MollieWebhookRequest
{
    /**
     * @var string
     */
    public $paymentId;

    /**
     * @var string
     */
    public $hookType;

    /**
     * @var Payment
     */
    public $payment;

    /**
     * @since 2.0.0
     *
     * @throws PaymentGatewayException
     */
    public static function fromArray(array $data): MollieWebhookRequest
    {
        $self = new self();


        $self->paymentId = $data['id'] ?? '';

        if (empty($self->paymentId)) {
            throw new PaymentGatewayException(__('[Mollie] Missing payment id.', 'give-mollie'));
        }

        $self->hookType = $data['hook_type'] ?? '';

        if (empty($self->hookType)) {
            throw new PaymentGatewayException(__('[Mollie] Missing hook type.', 'give-mollie'));
        }

        if (isset($data['payment']) && $data['payment'] instanceof Payment) {
            $self->payment = $data['payment'];
        } else {
            try {
                $self->payment = MollieApi::client()->payments->get($self->paymentId);
            } catch (ApiException $e) {
                throw new PaymentGatewayException(__('[Mollie] Payment not found.', 'give-mollie'));
            }
        }


        return $self;
    }
}
